@@ -53,17 +53,32 @@ class Entsoe():
                     tasks.append((url, area))
 
         indata_list = []
-        batch_size = self._batchsize
 
-        for batch in range(len(tasks) // batch_size + 1):
+        batch_size = 60
+        batch_duration = 10
+        batches = len(tasks) // batch_size
+        for batch in range(batches + 1):
             st = datetime.utcnow().timestamp()
             with ThreadPoolExecutor(max_workers=self._max_workers) as executor:
-                indata_list += list(executor.map(Entsoe._get_xml, tasks[batch * batch_size:(batch + 1) * batch_size]))
+                batch_list = list(executor.map(Entsoe._get_xml, tasks[batch * batch_size:(batch + 1) * batch_size]))
+                indata_list += [Entsoe._read_xml_A44(indata[0], indata[1]) for indata in batch_list]
             duration = datetime.utcnow().timestamp() - st
-            if duration < 61 and batch < len(tasks) // batch_size:
-                time.sleep(61 - duration)
-        indata_list = [Entsoe._read_xml_A44(indata[0], indata[1]) for indata in indata_list]
+            if duration < batch_duration and batch < batches:
+                print(f'waiting for {batch_duration - duration} after batch {batch} of {batches} with batch_duration={batch_duration}')
+                time.sleep(batch_duration - duration)
         indata_list = utils.flatten_list(indata_list)
+
+        # batch_size = int(self._batchsize/2)
+        #
+        # for batch in range(len(tasks) // batch_size + 1):
+        #     st = datetime.utcnow().timestamp()
+        #     with ThreadPoolExecutor(max_workers=self._max_workers) as executor:
+        #         indata_list += list(executor.map(Entsoe._get_xml, tasks[batch * batch_size:(batch + 1) * batch_size]))
+        #     duration = datetime.utcnow().timestamp() - st
+        #     if duration < 61 and batch < len(tasks) // batch_size:
+        #         time.sleep(61 - duration)
+        # indata_list = [Entsoe._read_xml_A44(indata[0], indata[1]) for indata in indata_list]
+        # indata_list = utils.flatten_list(indata_list)
         return indata_list
 
     @classmethod
