@@ -84,14 +84,14 @@ class Energidataservice:
                 (k, datetime.strptime(v, '%Y-%m-%dT%H:%M:%S')) for k, v in d.items() if (k in ['HourUTC', 'HourDK'] and v))
         return indata_json
 
-    @staticmethod
-    def transmission_lines_df(area, start_date=datetime(2020, 1, 1), end_date=datetime(2030, 12, 31)):
-        import pandas as pd
-        indata_list = Energidataservice.transmission_lines(area, start_date, end_date)
-        df = pd.DataFrame(indata_list)
-        df = df.pivot_table(index='HourUTC')
-        df = df.ffill()
-        return df
+    # @staticmethod
+    # def transmission_lines_df(area, start_date=datetime(2020, 1, 1), end_date=datetime(2030, 12, 31)):
+    #     import pandas as pd
+    #     indata_list = Energidataservice.transmission_lines(area, start_date, end_date)
+    #     df = pd.DataFrame(indata_list)
+    #     df = df.pivot_table(index='HourUTC')
+    #     df = df.ffill()
+    #     return df
 
 
 if __name__ == '__main__':
